@@ -52,6 +52,8 @@
 	#pragma clang diagnostic ignored "-Wshorten-64-to-32"
 #endif
 
+#define ASTYLE_VERSION "3.4.10"
+
 //-----------------------------------------------------------------------------
 // astyle namespace
 //-----------------------------------------------------------------------------
@@ -277,7 +279,7 @@ public:
 	static const std::string AS_SCOPE_RESOLUTION;
 	static const std::string AS_PLUS, AS_MINUS, AS_MULT, AS_DIV, AS_MOD, AS_GR, AS_LS;
 	static const std::string AS_NOT, AS_BIT_XOR, AS_BIT_OR, AS_BIT_AND, AS_BIT_NOT;
-	static const std::string AS_QUESTION, AS_COLON, AS_SEMICOLON, AS_COMMA;
+	static const std::string AS_QUESTION, AS_COLON, AS_SEMICOLON, AS_COMMA, AS_DOT;
 	static const std::string AS_ASM, AS__ASM__, AS_MS_ASM, AS_MS__ASM;
 	static const std::string AS_QFOREACH, AS_QFOREVER, AS_FOREVER;
 	static const std::string AS_FOREACH, AS_LOCK, AS_UNSAFE, AS_FIXED;
@@ -559,6 +561,9 @@ private:  // variables
 	bool shouldIndentPreprocConditional;
 	bool squeezeWhitespace;
 	bool attemptLambdaIndentation;
+
+	bool isInAssignment;
+
 	int  indentCount;
 	int  spaceIndentCount;
 	int  spaceIndentObjCMethodAlignment;
@@ -720,6 +725,9 @@ public:	// functions
 	void setOperatorPaddingMode(bool state);
 	void setParensOutsidePaddingMode(bool state);
 	void setParensFirstPaddingMode(bool state);
+
+	void setEmptyParensPaddingMode(bool state);
+
 	void setParensInsidePaddingMode(bool state);
 	void setParensHeaderPaddingMode(bool state);
 	void setParensUnPaddingMode(bool state);
@@ -940,6 +948,8 @@ private:  // variables
 	bool shouldPadOperators;
 	bool shouldPadParensOutside;
 	bool shouldPadFirstParen;
+
+	bool shouldPadEmptyParens;
 	bool shouldPadParensInside;
 	bool shouldPadHeader;
 	bool shouldStripCommentPrefix;
